std.vm.toy-interpreter


+block-context+clj

source

+primitives+clj

source

block-zipclj

(block-zip root)

creates a zipper for block

creates a zipper for block
sourceraw docstring

eval-primitiveclj

(eval-primitive op args)
source

expression?clj

(expression? b)

checks if a block is an expression (not whitespace/comment)

checks if a block is an expression (not whitespace/comment)
sourceraw docstring

find-redexclj

(find-redex z)

finds the next reducible expression zipper location

finds the next reducible expression zipper location
sourceraw docstring

find-redex-listclj

(find-redex-list z)
source

get-expressionsclj

(get-expressions b)

gets all non-whitespace children

gets all non-whitespace children
sourceraw docstring

highlight-nodeclj

(highlight-node z)
source

list-expression?clj

(list-expression? b)
source

lookup-symbolclj

(lookup-symbol sym env)

looks up a symbol in the environment

looks up a symbol in the environment
sourceraw docstring

macro?clj

(macro? op)
source

reduce-expressionclj

(reduce-expression z env)

reduces the expression at the zipper

reduces the expression at the zipper
sourceraw docstring

runclj

(run code-str)
source

run-formclj

(run-form form)
source

stepclj

(step z env)
source

substituteclj

(substitute body bind-sym bind-val)
source

symbol-token?clj

(symbol-token? b)
source

value?clj

(value? b)

checks if a block is a fully reduced value

checks if a block is a fully reduced value
sourceraw docstring

visualizeclj

(visualize z)
source

cljdoc builds & hosts documentation for Clojure/Script libraries