(block-zip root)creates a zipper for block
creates a zipper for block
(expression? b)checks if a block is an expression (not whitespace/comment)
checks if a block is an expression (not whitespace/comment)
(find-redex z)finds the next reducible expression zipper location
finds the next reducible expression zipper location
(get-expressions b)gets all non-whitespace children
gets all non-whitespace children
(lookup-symbol sym env)looks up a symbol in the environment
looks up a symbol in the environment
(reduce-expression z env)reduces the expression at the zipper
reduces the expression at the zipper
(value? b)checks if a block is a fully reduced value
checks if a block is a fully reduced value
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |